pub fn enable_phy<'d>() -> PhyInitGuard<'d>Expand description
Enable the PHY.
If no other PhyInitGuard is currently alive, this will also initialize the PHY, which will involve a full RF calibration, unless you loaded previously backed up calibration data with set_phy_calibration_data.